import sys
import re
import json
from typing import List, Tuple

def get_keys_values(stmt: str) -> Tuple[str, str]:
    format = lambda tks: [tk.strip() for tk in tks.split(',')]
    keys, _, values = re.search(r'\((.+?)\)(\s*values\s*)\((.+)\)', stmt).groups() 
    return format(keys), format(values)

def parse_stmt(keys: List[str], values: List[str]) -> List[Tuple[str, str]]:
    return dict([(k,v) for k, v in zip(keys, values)])

def sql2json(stmt: str) -> str:
    keys, values = get_keys_values(stmt)
    return parse_stmt(keys, values)

def read_input()-> str:
    if len(sys.argv) != 2:
        raise Exception('usage: json2sql "insert into table(column) values(1)"')
    return sys.argv[1]

def main():
    stmt = read_input()
    obj = sql2json(stmt)
    js = json.dumps(obj)
    print(js)
if __name__ == '__main__':
    main()


import unittest
from  sql22json.main import sql2json

from typing import Dict

class TestSql2Json(unittest.TestCase):

    def assertResult(self, stmt: str, expected: Dict[str,str]):
        self.assertEqual(sql2json(stmt), expected)

    def test_one_column(self):
        stmt = "insert into table( column ) values(1)"
        expected = {
            'column': '1'
        }
        self.assertResult(stmt, expected)

    def test_many_columns(self):
        stmt = "insert into person( id, name, type, salary ) values (1, 'Obi Wan', 'Jedi', 1.12)"
        expected = {
            'id': '1',
            'name': "'Obi Wan'",
            'type': "'Jedi'",
            'salary':'1.12'
        }
        self.assertResult(stmt, expected)
    
    def test_function_value(self):
        stmt = "insert into event( id, date ) values (1, curdate('now'))"
        expected = {
            'id': '1',
            'date': "curdate('now')",
        }
        self.assertResult(stmt, expected)
    
        

if __name__ == "__main__":
    unittest.main()


from setuptools import setup, find_packages

setup(
    name='sql22json',
    version='0.1.1',
    license='MIT',
    author='Gabriel Fr. Borges',
    author_email='gabrielfr.borges@gmail.com',
    url='https://github.com/gfborges/sql22json',
    download_url = 'https://github.com/gfborges/sql22json/releases/download/0.1.0/sql22json-0.1.0.tar.gz',
    packages=find_packages(),
    entry_points= {
        'console_scripts':{
            'sql22json = sql22json.main:main'
        }
    }
)